{% import 'macros/form.html' as form %}

<form id="dataset-edit" class="dataset-form" method="post" action="{{ action }}" data-module="basic-form" novalidate>
    {{ form.select('type', label=_('Type'), options=package_types) }}
    <div class="form-actions">
        <button class="btn btn-primary" type="submit" name="save">{% block save_button_text %}{{ _('Next: Add Data') }}{% endblock %}</button>

    </div>
</form>
